@@ -9,6 +9,7 @@ import enum
 import hashlib
 import logging
 import shutil
+import time
 from pathlib import Path
 from typing import Any, Iterator, Sequence, cast
 
@@ -189,7 +190,7 @@ class BuildEnvironment:
     def exists(self) -> bool:
         """Returns `True` if the environment exists."""
 
-        return self._path.is_file()
+        return self._path.exists()
 
     def remove(self) -> None:
         """Remove the virtual environment."""
@@ -223,11 +224,15 @@ class BuildEnvironment:
             config = self._get_pex_build_config(requirements)
 
             logger.info("Resolving ...")
+            tstart = time.perf_counter()
             resolved = config.resolve()
+            logger.info("Resolve complete (%fs)", time.perf_counter() - tstart)
 
             logger.info("Building ...")
+            tstart = time.perf_counter()
             builder = config.builder(resolved)
             builder.build(str(self._path), layout=self._type.to_pex_layout())
+            logger.info("Build complete (%fs)", time.perf_counter() - tstart)
 
         else:
             raise RuntimeError(f"Not supported: {self._type!r}")
@@ -244,7 +249,8 @@ class BuildEnvironment:
         interpreter_constraints = [requirements.interpreter_constraint] if requirements.interpreter_constraint else []
 
         # Ensure with the preamble that the local python paths are importable.
-        preamble = "# kraken-cli BEGIN\nimport sys\n"
+        preamble = "# kraken-cli BEGIN\nimport os, sys\n"
+        preamble += "os.environ.setdefault('KRAKEN_MANAGED', '1')\n"
         for path in (self._project_path / x for x in requirements.pythonpath):
             preamble += f"sys.path.append({str(path.absolute())!r})\n"
         preamble += "# kraken-cli END\n"
