@@ -99,35 +99,45 @@ class BuildAwareCommand(Command):
         self,
         build_env: BuildEnvironment,
         project: ProjectInterface,
-        force: bool = False,
+        upgrade: bool = False,
+        reinstall: bool = False,
     ) -> tuple[InstallSource, InstallResult]:
         """Make sure that the build environment exists and the requirements are installed.
 
         :param build_env: The build environment to ensure is up to date.
         :param project: Implementation that provides access to the requirement spec and lockfile.
-        :param force: If set to `True`, ignore the lock file and existing build environment.
+        :param upgrade: If set to `True`, ignore the lock file and existing build environment.
+        :param reinstall: If set to `True`, ignore the build environment, but use the lock file.
         """
 
         requirements = project.get_requirement_spec()
         lockfile_path = project.get_lock_file()
         lockfile = Lockfile.from_path(lockfile_path)
 
-        if force and lockfile:
-            logger.info("Ignoring lockfile (%s)", lockfile_path)
+        if upgrade and lockfile:
+            logger.info("Ignoring lockfile (%s) (upgrade=True)", lockfile_path)
             lockfile = None
 
-        build_env_existed = build_env.exists()
-        if os.getenv("KRAKEN_REINSTALL_BUILD_ENV") == "1" and build_env.exists():
-            logger.info(
-                "Ignoring existing build environment (%s) because of KRAKEN_REINSTALL_BUILD_ENV=1",
-                build_env.path,
-            )
-
         install_required = not build_env.exists()
-        if force and build_env.exists():
-            logger.info("Ignoring existing build environment (%s)", build_env.path)
+        if upgrade and build_env.exists():
+            logger.info("Ignoring existing build environment (%s) (upgrade=True)", build_env.path)
             install_required = True
 
+        build_env_existed = build_env.exists()
+        if not install_required:
+            if os.getenv("KRAKEN_REINSTALL_BUILD_ENV") == "1" and build_env.exists():
+                logger.info(
+                    "Ignoring existing build environment (%s) (KRAKEN_REINSTALL_BUILD_ENV=1)",
+                    build_env.path,
+                )
+                install_required = True
+            elif reinstall and build_env.exists():
+                logger.info(
+                    "Ignoring existing build environment (%s) (reinstall=True)",
+                    build_env.path,
+                )
+                install_required = True
+
         source: RequirementSpec | Lockfile = requirements
         source_type = InstallSource.REQUIREMENTS
 
@@ -160,7 +170,7 @@ class BuildAwareCommand(Command):
             )
             return source_type, (
                 InstallResult.UPGRADED
-                if build_env_existed and force
+                if build_env_existed and upgrade
                 else InstallResult.UPDATED
                 if build_env_existed
                 else InstallResult.INSTALLED
